@@ -1,5 +1,5 @@
 ;; -*- no-byte-compile: t; lexical-binding: nil -*-
-(define-package "mu4e-views" "0.8"
+(define-package "mu4e-views" "20251130.249"
   "View emails in mu4e using xwidget-webkit."
   '((emacs          "26.1")
     (xwidgets-reuse "0.3")
@@ -7,7 +7,7 @@
     (esxml          "20210323.1102"))
   :url "https://github.com/lordpretzel/mu4e-views"
   :commit "892ea3163fa4964e9fc99e732e0c0d21d4931ae7"
-  :revdesc "0.8-0-g892ea3163fa4"
+  :revdesc "892ea3163fa4"
   :keywords '("mail")
   :authors '(("Boris Glavic" . "lordpretzel@gmail.com"))
   :maintainers '(("Boris Glavic" . "lordpretzel@gmail.com")))
